Expose the original packet length in in the RTP play tools.

R=henrik.lundin@webrtc.org

Review URL: https://webrtc-codereview.appspot.com/14579004

git-svn-id: http://webrtc.googlecode.com/svn/trunk@6198 4adac7df-926f-26a2-2b94-8c16560cd09d
diff --git a/webrtc/modules/video_coding/main/test/rtp_file_reader.cc b/webrtc/modules/video_coding/main/test/rtp_file_reader.cc
index 447eb9b..2ab5460 100644
--- a/webrtc/modules/video_coding/main/test/rtp_file_reader.cc
+++ b/webrtc/modules/video_coding/main/test/rtp_file_reader.cc
@@ -103,10 +103,11 @@
   }
 
   virtual int NextPacket(uint8_t* rtp_data, uint32_t* length,
-                         uint32_t* time_ms) {
+                         uint32_t* time_ms, uint32_t* original_length) {
     assert(rtp_data);
     assert(length);
     assert(time_ms);
+    assert(original_length);
 
     uint16_t len;
     uint16_t plen;
@@ -126,6 +127,7 @@
 
     *length = len;
     *time_ms = offset;
+    *original_length = plen;
     return kResultSuccess;
   }
 
diff --git a/webrtc/modules/video_coding/main/test/rtp_player.h b/webrtc/modules/video_coding/main/test/rtp_player.h
index 24e62b6..c945b5c 100644
--- a/webrtc/modules/video_coding/main/test/rtp_player.h
+++ b/webrtc/modules/video_coding/main/test/rtp_player.h
@@ -53,9 +53,10 @@
   // Read next RTP packet into buffer pointed to by rtp_data. On call, 'length'
   // field must be filled in with the size of the buffer. The actual size of
   // the packet is available in 'length' upon returning. Time in milliseconds
   // from start of stream is returned in 'time_ms'.
   virtual int NextPacket(uint8_t* rtp_data, uint32_t* length,
-                         uint32_t* time_ms) = 0;
+                         uint32_t* time_ms, uint32_t* original_length) = 0;
 };
 
 // Implemented by RtpPlayer and given to client as a means to retrieve
@@ -53,9 +53,10 @@
   // field must be filled in with the size of the buffer. The actual size of
   // the packet is available in 'length' upon returning. Time in milliseconds
-  // from start of stream is returned in 'time_ms'.
+  // from start of stream is returned in 'time_ms'.  The original full length
+  // of the packet is returned in 'original_length'.
   virtual int NextPacket(uint8_t* rtp_data, uint32_t* length,